
from models import run_models

from argparse import ArgumentParser
from subprocess import call
from sys import platform


def run_model(args):
    call(f"/media/bram/PlayField/Projects/Freelancing/Ritesh_YOLO/yolo_as_one/src/inference_scripts/{args.model_name}.sh {args.source} {args.save_dir}", shell=True)

    pass

if __name__ == "__main__":

    parser = ArgumentParser()
    parser.add_argument("--model_name", type=str,
                        help="specify the model to test")
    parser.add_argument("--source",
                        help="specify the source: image, video or webcam=0",
                        default='image')
    parser.add_argument("--save_dir",type=str, help="results are saved here",
                        default=False)
    parser.add_argument('--view_img', action='store_true', help='show results',
                        default=False)
    args = parser.parse_args()
    # demo code
    run_model(args)





import argparse
from subprocess import call
from sys import platform

model_names = ['yolox', 'yolor', 'yolov5']

def parse_args():
    parse = argparse.ArgumentParser()
    parse.add_argument('--model_name', default='None')
    return parse.parse_args()


def install_models(model_name):
    if model_name in model_names:
        if platform == "linux" or platform == "linux2":
            call(f"{model_name}_installation.sh", shell=True)
        elif platform == "win32":
            call(f"{model_name}_installation.bat", shell=True)
        else:
            print('Operating Sytem unsupported')
    else:
        print('model currently unavailable')
    pass

def run_models(args):
    if args.model_name in model_names:
        if platform == "linux" or platform == "linux2":
            call(f"{args.model_name}_inferencing.sh {args.source} {args.save_dir}", shell=True)
        elif platform == "win32":
            call(f"{args.model_name}_inferencing.bat", shell=True)
        else:
            print('Operating Sytem unsupported')
    else:
        print('model currently unavailable')
    pass


if __name__=='__main__':
    args = parse_args()
    install_models(args.model_name)



from setuptools import setup, find_packages
from sys import platform

pycoco = 'pycocotools' if platform=='linux' else 'pycocotools-windows'

print(pycoco)

setup(
    name='yolo_as_one',
    version='0.5.9',
    license='MIT',
    author="Bramwel Ochieng",
    author_email='lol@gmail.com',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    url='https://github.com/ochi96/yolo_as_one',
    keywords='yolox yolor yolov5 installation inferencing',
    install_requires=[
        'scikit-learn',
        'wheel',
        'numpy',
        'torch>=1.7.0',
        'opencv_python',
        'loguru',
        'scikit-image',
        'tqdm',
        'torchvision',
        'Pillow',
        'thop',
        'ninja',
        'tabulate',
        'tensorboard',
        'PyYAML>=5.3.1',
        'pandas>=1.1.4',
        'seaborn>=0.11.0',
        'thop',
        'requests>=2.23.0',
        'matplotlib>=3.2.2',
        pycoco,
        'gdown',
        'pytorch_wavelet'
      ],

    scripts=[
        './src/installation_scripts/yolor_installation.sh',
        './src/installation_scripts/yolox_installation.sh',
        './src/installation_scripts/yolov5_installation.sh',
        './src/installation_scripts/yolor_installation.bat',
        './src/installation_scripts/yolox_installation.bat',
        './src/installation_scripts/yolov5_installation.bat',
        './src/inference_scripts/yolor_inferencing.sh',
        './src/inference_scripts/yolox_inferencing.sh',
        './src/inference_scripts/yolov5_inferencing.sh',
        './src/inference_scripts/yolor_inferencing.bat',
        './src/inference_scripts/yolox_inferencing.bat',
        './src/inference_scripts/yolov5_inferencing.bat',

    ]
)